@@ -23,6 +23,7 @@ from .delete_sandbox_preview_token_response_200 import DeleteSandboxPreviewToken
 from .delete_workspace_service_account_response_200 import DeleteWorkspaceServiceAccountResponse200
 from .entrypoint import Entrypoint
 from .entrypoint_env import EntrypointEnv
+from .expiration_policy import ExpirationPolicy
 from .flavor import Flavor
 from .form import Form
 from .form_config import FormConfig
@@ -113,6 +114,7 @@ from .private_cluster import PrivateCluster
 from .private_location import PrivateLocation
 from .public_ip import PublicIp
 from .public_ips import PublicIps
+from .region import Region
 from .repository import Repository
 from .request_duration_over_time_metric import RequestDurationOverTimeMetric
 from .request_duration_over_time_metrics import RequestDurationOverTimeMetrics
@@ -146,6 +148,7 @@ from .runtime_configuration import RuntimeConfiguration
 from .runtime_startup_probe import RuntimeStartupProbe
 from .sandbox import Sandbox
 from .sandbox_definition import SandboxDefinition
+from .sandbox_lifecycle import SandboxLifecycle
 from .sandbox_spec import SandboxSpec
 from .serverless_config import ServerlessConfig
 from .serverless_config_configuration import ServerlessConfigConfiguration
@@ -170,6 +173,10 @@ from .trigger_configuration_task import TriggerConfigurationTask
 from .update_workspace_service_account_body import UpdateWorkspaceServiceAccountBody
 from .update_workspace_service_account_response_200 import UpdateWorkspaceServiceAccountResponse200
 from .update_workspace_user_role_body import UpdateWorkspaceUserRoleBody
+from .volume import Volume
+from .volume_attachment import VolumeAttachment
+from .volume_spec import VolumeSpec
+from .volume_state import VolumeState
 from .websocket_channel import WebsocketChannel
 from .websocket_message import WebsocketMessage
 from .workspace import Workspace
@@ -201,6 +208,7 @@ __all__ = (
     "DeleteWorkspaceServiceAccountResponse200",
     "Entrypoint",
     "EntrypointEnv",
+    "ExpirationPolicy",
     "Flavor",
     "Form",
     "FormConfig",
@@ -289,6 +297,7 @@ __all__ = (
     "PrivateLocation",
     "PublicIp",
     "PublicIps",
+    "Region",
     "Repository",
     "RequestDurationOverTimeMetric",
     "RequestDurationOverTimeMetrics",
@@ -316,6 +325,7 @@ __all__ = (
     "RuntimeStartupProbe",
     "Sandbox",
     "SandboxDefinition",
+    "SandboxLifecycle",
     "SandboxSpec",
     "ServerlessConfig",
     "ServerlessConfigConfiguration",
@@ -340,6 +350,10 @@ __all__ = (
     "UpdateWorkspaceServiceAccountBody",
     "UpdateWorkspaceServiceAccountResponse200",
     "UpdateWorkspaceUserRoleBody",
+    "Volume",
+    "VolumeAttachment",
+    "VolumeSpec",
+    "VolumeState",
     "WebsocketChannel",
     "WebsocketMessage",
     "Workspace",
